@@ -517,6 +517,7 @@ def store_assets():
 
                         # This a new asset so persist it
                         assets_to_persist.append(asset)
+                        images_to_regenerate[version] = asset
 
                         if current_image_set \
                                 and current_image_set.images.get(version):
@@ -527,26 +528,6 @@ def store_assets():
                                 current_image_set.images[version]
                             )
 
-                        # Determine if we need to generate variations of this
-                        # asset.
-                        if version == image_set.base_version:
-                            for v in asset.variations.keys():
-                                if v == image_set.base_version \
-                                        and image_set.base_transforms.get(v):
-
-                                    images_to_regenerate[version] = asset
-                                    break
-
-                                if v not in image_set.images \
-                                        and image_set.base_transforms.get(v):
-
-                                    images_to_regenerate[version] = asset
-                                    break
-
-                        else:
-                            if image_set.base_transforms.get(version):
-                                images_to_regenerate[version] = asset
-
                     else:
 
                         # Determine if we need to generate variations of this
@@ -580,19 +561,19 @@ def store_assets():
                 # Build the transform instructions required to regenerate
                 # variations for the assets in the image set.
 
+                # Get variations defined for the field against the manage
+                # config.
+                field_variations = state.manage_config.asset_variations.get(
+                    field,
+                    {}
+                )
+
                 for version, asset in images_to_regenerate.items():
 
-                    # Get variations defined for the field against the manage
-                    # config.
-                    variations = state.manage_config.asset_variations.get(
-                        field,
-                        {}
-                    )
-
-                    # Copy the variations structure
+                    # Copy the field variations structure
                     variations = {
                         k: [i for i in v]
-                        for k, v in variations.items()
+                        for k, v in field_variations.items()
                     }
 
                     # If this isn't the base version of the image set remove
@@ -637,16 +618,13 @@ def store_assets():
                             base_transforms = []
 
                             if k in image_set.base_transforms:
-                                if version != image_set.base_version \
-                                        or k not in image_set.images \
-                                        or k == image_set.base_version:
 
-                                    base_transforms = [
-                                        BaseTransform.from_json_type(t)
-                                        for t in image_set.base_transforms[k]
-                                    ]
+                                base_transforms = [
+                                    BaseTransform.from_json_type(t)
+                                    for t in image_set.base_transforms[k]
+                                ]
 
-                            variations[k] = base_transforms + variations[k]
+                            variations[k] = base_transforms + v
 
                         # Add the tranform information for the asset (the asset,
                         # variations and base transforms).
@@ -657,7 +635,7 @@ def store_assets():
 
                     # Image set has been removed so remove all image assets
                     # associated with it.
-                    for image in document[field].images:
+                    for image in document[field].images.values():
                         assets_to_remove.append(image)
 
         # Store assets permanently
